[−][src]Struct sp_runtime::offchain::http::Headers
A collection of Headers in the response.
Fields
raw: Vec<(Vec<u8>, Vec<u8>)>Raw headers
Implementations
impl Headers[src][−]
pub fn find(&self, name: &str) -> Option<&str>[src][−]
Retrieve a single header from the list of headers.
Note this method is linearly looking from all the headers comparing them with the needle byte-by-byte. If you want to consume multiple headers it's better to iterate and collect them on your own.
pub fn into_iter(&self) -> HeadersIterator<'_>[src][−]
Convert this headers into an iterator.