[−][src]Struct sp_runtime::offchain::http::Request
An HTTP request builder.
Fields
method: MethodRequest method
url: &'a strRequest URL
body: TBody of the request
deadline: Option<Timestamp>Deadline to finish sending the request
Implementations
impl<'a> Request<'a>[src][−]
impl<'a, T> Request<'a, T>[src][−]
impl<'a, T: Default> Request<'a, T>[src][−]
pub fn new(url: &'a str) -> Self[src][−]
Create a new Request builder with the given URL.
pub fn method(self, method: Method) -> Self[src][−]
Change the method of the request
pub fn url(self, url: &'a str) -> Self[src][−]
Change the URL of the request.
pub fn body(self, body: T) -> Self[src][−]
Set the body of the request.
pub fn add_header(self, name: &str, value: &str) -> Self[src][−]
Add a header.
pub fn deadline(self, deadline: Timestamp) -> Self[src][−]
Set the deadline of the request.
impl<'a, I: AsRef<[u8]>, T: IntoIterator<Item = I>> Request<'a, T>[src][−]
pub fn send(self) -> Result<PendingRequest, HttpError>[src][−]
Send the request and return a handle.
Err is returned in case the deadline is reached or the request timeouts.